<template>
  <div class="q-ma-lg">
    <h4>Thanks for registering!</h4>
    <p>You can now log in <router-link to="/login">here</router-link>.</p>
  </div>
</template>

<script>
export default {};
</script>

<style>
</style>
